"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import lakefs_client
from lakefs_client.api.commits_api import CommitsApi  # noqa: E501


class TestCommitsApi(unittest.TestCase):
    """CommitsApi unit test stubs"""

    def setUp(self):
        self.api = CommitsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_commit(self):
        """Test case for commit

        create commit  # noqa: E501
        """
        pass

    def test_get_commit(self):
        """Test case for get_commit

        get commit  # noqa: E501
        """
        pass

    def test_log_branch_commits(self):
        """Test case for log_branch_commits

        get commit log from branch. Deprecated: replaced by logCommits by passing branch name as ref   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
