"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import lakefs_client
from lakefs_client.api.staging_api import StagingApi  # noqa: E501


class TestStagingApi(unittest.TestCase):
    """StagingApi unit test stubs"""

    def setUp(self):
        self.api = StagingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_physical_address(self):
        """Test case for get_physical_address

        get a physical address and a return token to write object to underlying storage  # noqa: E501
        """
        pass

    def test_link_physical_address(self):
        """Test case for link_physical_address

        associate staging on this physical address with a path  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
